import { Action } from "./reducer";
declare type DeferLiteralArrayCheck<T> = T extends Array<string | number | boolean | null | undefined> ? any[] : never;
export declare function useLoadingStatus(identifier?: string): boolean;
/**
 * For actions like:
 * *foo(a: number, b: string, c: boolean): SagaIterator {..}
 *
 * useModuleAction(foo) will return:
 * (a: number, b: string, c: boolean) => void;
 *
 * useModuleAction(foo, 100) will return:
 * (b: string, c: boolean) => void;
 *
 * useModuleAction(foo, 100, "") will return:
 * (c: boolean) => void;
 *
 * useModuleAction(foo, 100, "", true) will return:
 * () => void;
 */
export declare function useModuleAction<T extends any[], U extends any[]>(actionCreator: (...args: [...T, ...U]) => Action<[...DeferLiteralArrayCheck<T>, ...U]>, ...deps: T): (...args: U) => void;
/**
 * For actions like:
 * *foo(data: {key: number}): SagaIterator {..}
 *
 * useModuleObjectAction(foo, "key") will return:
 * (objectValue: number) => void;
 */
export declare function useModuleObjectAction<T extends object, K extends keyof T>(actionCreator: (arg: T) => Action<[T]>, objectKey: K): (objectValue: T[K]) => void;
export {};
